@@ -8,7 +8,7 @@ use strict;
 
 package CPAN::Site::Index;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 use base 'Exporter';
 
@@ -51,6 +51,7 @@ sub cpan_mirror($$$@);
 
 sub safe_copy($$)
 {   my ($from, $to) = @_;
+    trace "copy $from to $to";
     copy $from, $to
         or fault __x"cannot copy {from} to {to}", from => $from, to => $to;
 }
@@ -215,13 +216,17 @@ sub collect_package_details($$)
         }
 
         if( m/^ (?:use\s+version\s*;\s*)?
-            (?:our)? \s* \$ (?: \w+\:\:)* VERSION \s* \= \s* (.*)/x )
-        {   defined $1 or next;
+            (?:our)? \s* \$ ((?: \w+\:\:)*) VERSION \s* \= \s* (.*)/x )
+        {   defined $2 or next;
+            my ($ns, $vers) = ($1, $2);
             local $VERSION;  # destroyed by eval
-            $version = eval "my \$v = $1";
+            $version = eval "my \$v = $vers";
             $version = $version->numify if ref $version;
             if(defined $version)
-            {   trace "pkg $package version $version";
+            {   ($package = $ns) =~ s/\:\:$//
+                    if length $ns;
+
+                trace "pkg $package version $version";
                 register $package, $version, $dist;
             }
         }
@@ -397,6 +402,7 @@ sub cpan_mirror($$$@)
     {   last if $line =~ m/^\s*$/;
     }
 
+    $ua ||= LWP::UserAgent->new;
     while(my $line = $fh->getline)
     {   my ($pkg, $version, $dist) = split ' ', $line;
         delete $need{$pkg} or next;
